==> jc-1.4.0.tar.gz: soot/toolkits/scalar/LocalUnitPair.h <==
// public class soot.toolkits.scalar.LocalUnitPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c2e5d6c5ba90342c soot_toolkits_scalar_LocalUnitPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_LocalUnitPair_H_
#define _JC_soot_toolkits_scalar_LocalUnitPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs	_jc_soot_toolkits_scalar_LocalUnitPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs	_jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$refs	_jc_soot_toolkits_scalar_LocalUnitPair$refs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$nonrefs	_jc_soot_toolkits_scalar_LocalUnitPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$object	_jc_soot_toolkits_scalar_LocalUnitPair$object;

typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vmethods	_jc_soot_toolkits_scalar_LocalUnitPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vtable	_jc_soot_toolkits_scalar_LocalUnitPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vtype	_jc_soot_toolkits_scalar_LocalUnitPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_LocalUnitPair$method$_init$c8d88dbaa0bf1f33(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_LocalUnitPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_toolkits_scalar_LocalUnitPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_LocalUnitPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_LocalUnitPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_LocalUnitPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_LocalUnitPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_LocalUnitPair$vmethods	soot_toolkits_scalar_LocalUnitPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_LocalUnitPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_LocalUnitPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs {
	struct _jc_object	*local;
	struct _jc_object	*unit;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_LocalUnitPair$refs {
    _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs	soot_toolkits_scalar_LocalUnitPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_LocalUnitPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs	soot_toolkits_scalar_LocalUnitPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_LocalUnitPair$object {
	_jc_soot_toolkits_scalar_LocalUnitPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_LocalUnitPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_LocalUnitPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_LocalUnitPair$vtype _jc_soot_toolkits_scalar_LocalUnitPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_LocalUnitPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_LocalUnitPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_LocalUnitPair_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/LocalUnitPair.h <==
// public class soot.toolkits.scalar.LocalUnitPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c2e5d6c5ba90342c soot_toolkits_scalar_LocalUnitPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_LocalUnitPair_H_
#define _JC_soot_toolkits_scalar_LocalUnitPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs	_jc_soot_toolkits_scalar_LocalUnitPair$sub_refs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs	_jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$refs	_jc_soot_toolkits_scalar_LocalUnitPair$refs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$nonrefs	_jc_soot_toolkits_scalar_LocalUnitPair$nonrefs;
typedef struct _jc_soot_toolkits_scalar_LocalUnitPair$object	_jc_soot_toolkits_scalar_LocalUnitPair$object;

typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vmethods	_jc_soot_toolkits_scalar_LocalUnitPair$vmethods;
typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vtable	_jc_soot_toolkits_scalar_LocalUnitPair$vtable;
typedef const struct _jc_soot_toolkits_scalar_LocalUnitPair$vtype	_jc_soot_toolkits_scalar_LocalUnitPair$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_LocalUnitPair$method$_init$c8d88dbaa0bf1f33(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_toolkits_scalar_LocalUnitPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_LocalUnitPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_LocalUnitPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_toolkits_scalar_LocalUnitPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_LocalUnitPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_toolkits_scalar_LocalUnitPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_LocalUnitPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_LocalUnitPair$vmethods	soot_toolkits_scalar_LocalUnitPair;
};

// Vtype
struct _jc_soot_toolkits_scalar_LocalUnitPair$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_LocalUnitPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs {
	struct _jc_object	*local;
	struct _jc_object	*unit;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_LocalUnitPair$refs {
    _jc_soot_toolkits_scalar_LocalUnitPair$sub_refs	soot_toolkits_scalar_LocalUnitPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_LocalUnitPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_LocalUnitPair$sub_nonrefs	soot_toolkits_scalar_LocalUnitPair;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_LocalUnitPair$object {
	_jc_soot_toolkits_scalar_LocalUnitPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_LocalUnitPair$vtype	*vtype;
	_jc_soot_toolkits_scalar_LocalUnitPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_LocalUnitPair$vtype _jc_soot_toolkits_scalar_LocalUnitPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_LocalUnitPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_LocalUnitPair$class_object;

#endif	/* _JC_soot_toolkits_scalar_LocalUnitPair_H_ */
